@@ -443,7 +443,7 @@ def get_keywords_metrics(email,api_key,df,match_extract):
         post_data[len(post_data)] = dict(
             location_code=2840,
             keywords=keywords_list,
-            date_from="2021-08-01",
+            # date_from="2021-08-01",
             search_partners=True
         )
         response = client.post(
